#
# spec file for package python-python-xlib
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_with     test
%define         X_display         ":98"
%define         oldpython python
Name:           python-python-xlib
Version:        0.19
Release:        2.1
Summary:        Python X11 interface
License:        LGPL-2.1+
Group:          Development/Libraries/Python
Url:            https://github.com/python-xlib/python-xlib
Source:         https://files.pythonhosted.org/packages/source/p/python-xlib/python-xlib-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM python-xlib-0.14-increase-receiving-buffer.patch deb#357507
Patch0:         python-xlib-0.14-increase-receiving-buffer.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module six >= 1.10.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  xorg-x11-server
%endif
Requires:       python-six >= 1.10.0
%ifpython2
Provides:       %{oldpython}-xlib = %{version}
Obsoletes:      %{oldpython}-xlib < %{version}
%endif
%ifpython3
Provides:       python3-xlib = %{version}
Obsoletes:      python3-xlib < %{version}
%endif
BuildArch:      noarch

%python_subpackages

%description
The Python X Library is intended to be a fully functional X client
library for Python programs.

%prep
%setup -q -n python-xlib-%{version}
%patch0 -p1

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with test}
%check
export DISPLAY=%{X_display}
Xvfb %{X_display} >& Xvfb.log &
trap "kill $! || true" EXIT
sleep 10
%python_exec runtests.py
%endif

%files %{python_files}
%defattr(-,root,root)
%doc LICENSE README.rst NEWS TODO
%{python_sitelib}/Xlib/
%{python_sitelib}/python_xlib-*py*.egg-info

%changelog
* Thu Aug 31 2017 toddrme2178@gmail.com
- Update to Version 0.19
  + Bug Fixes
  * don't throw an exception if $XAUTHFILE / ~/.Xauthority is missing
  * fix authentication work-around for SSH forwarding under Python 3
  * improve $DISPLAY handling: support optional protocol prefix, and
    correctly handle `unix:0.0` as `:0.0`
- Update to  Version 0.18
  + Bug Fixes
  * fix Python 3 buffer abstraction
  * fix interrupted select handling for Python 3.3/3.4
  * fix Unix socket support when only an abstract address is available
- Update to  Version 0.17
  + Bug Fixes
  * fix Xauth handling when using Python 2 and DISPLAY contains a remote IP
  * fix String16 request field handling when using Python 3
  * fix RECORD extension and example when using Python 3
  * fix handling of properties: use byte strings for all X11 8-bits
    strings, as not all of them are text properties (the window
    getters/setters for wm_name, wm_icon_name, wm_class, and
    wm_client_machine still return/expect Unicode strings)
  + API Changes
  * Core:
    > new window getter/setter for text properties: get_full_text_property
    and change_text_property; with automatic conversion to/from Unicode
    when the property type encoding is supported (STRING and UTF8_STRING)
  * Composite extension:
    > support for GetOverlayWindow request
- Update to  Version 0.16
  + Licensing
  * The project is now licensed under the GNU Lesser General Public License
    v2.1 or later (see the LICENSE file for details).
  + Compatibility
  * Support for Python versions older than 2.7 has been dropped. Support for
    Python 3 (3.3, 3.4 and 3.5) has been added. Note that Python-Xlib now
    depends on the six package (>=1.10) for combined Python 2 / 3 support.
  + API Changes
  * With the change of license, and no way to contact the original author of
    the SHAPE extension, the code had to be rewritten from scratch. This
    resulted in a few minor API changes (see examples/shapewin.py).
  * Partial support for the SECURITY. XInput, and XFIXES extensions has been
    added.
  + Bug Fixes
  * fix RECORD extension
  * fixed OS X socket path
  * fix handling of generic events
  * fix handling of KeymapNotify events
  * several fixes for the RandR extension
- Update to Version 0.15rc1
  + Composite extension
  * Support for the composite extension, used to implement a composition
    manager (added for plcm work in plwm).
  + XF86 special function keysyms
  * Keysym definitions for special function keys found on modern
    keyboards, e.g. raise and lower volume, start specific applications,
    etc.  Have a look in Xlib/keysymdef/xf86.py to see what there are and
    experiment with xev to see what your keyboard generates.  These
    definitions aren't brought in by default, so you must do this after
    importing Xlib.XK:
  * Xlib.XK.load_keysym_group('xf86')
  + RANDR extension
  * The RANDR extension complements XINERAMA as a way of getting data about the
    physical screens making up a virtual screen in X. An example of usage can
    be found in examples/xrandr.py.
- Rename to python-python-xlib to follow python package
  naming rules.
- Change license to LGPL-2.1+
- Remove upstream-included patches:
  * python-xlib-0.14-fix-unix-socket-in-display.patch
  * python-xlib-0.14-xauthlocalhostname.patch
- Rebase python-xlib-0.14-increase-receiving-buffer.patch
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Wed Jan  2 2013 toddrme2178@gmail.com
- Fix building on SLES
* Mon Sep  3 2012 jengelh@inai.de
- Remove redundant (%%clean, Authors) sections
- Make package compile on RH6-like as well
* Thu Aug 19 2010 gber@opensuse.org
- added  python-xlib-0.14-xauthlocalhostname.patch which takes
  XAUTHLOCALHOSTNAME into account when connecting to a local Unix
  socket, this fixes python-xlib when logging in with gdm/xdm
  (bnc#623507)
- removed python-xlib-0.14-fix-ssh-tunnel-auth.patch, already taken
  care of
* Wed Aug 11 2010 gber@opensuse.org
- Add selected patches from Debian
  + python-xlib-0.14-fix-unix-socket-in-display.patch: partial fix
    for crash when unix is explicitly specified in DISPLAY
  + python-xlib-0.14-increase-receiving-buffer.patch: fix problem
    with too small receiving buffer
  + python-xlib-0.14-fix-ssh-tunnel-auth.patch: partial fix for X
    tunneling through OpenSSH
* Wed Oct 31 2007 jpr@suse.de
- Python bindings for Xlib
- Initial checkin of version 0.14
